@@ -15,13 +15,15 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: IniParseFeedback.cc,v 2.1 2002/05/19 12:58:24 rbcollins Exp $\n";
+  "\n%%% $Id: IniParseFeedback.cc,v 2.2 2002/06/26 21:35:15 rbcollins Exp $\n";
 #endif
 
 #include "IniParseFeedback.h"
 
 IniParseFeedback::~IniParseFeedback(){}
 
+void IniParseFeedback::progress(unsigned long const, unsigned long const) {}
+void IniParseFeedback::iniName (String const &) {}
 void IniParseFeedback::babble(String const &) const {}
 void IniParseFeedback::warning (String const &) const {}
 void IniParseFeedback::error(String const &) const {}
