@@ -13,15 +13,23 @@
  *
  */
 
-/* A user-related settings */
+#ifndef SETUP_USERSETTING_H
+#define SETUP_USERSETTING_H
 
-#ifndef _USERSETTING_H_
-#define _USERSETTING_H_
+/* A user-related settings */
 
 class UserSetting {
   public:
-  UserSetting();
   virtual ~UserSetting();
+  virtual void load() = 0;
+  virtual void save() = 0;
+  protected:
+  UserSetting();
+  private:
+  /* not implemented */
+  UserSetting(UserSetting const &);
+  UserSetting &operator=(UserSetting const &);
+  friend class UserSettingTest;
 };
 
-#endif /* _USERSETTING_H_ */
+#endif /* SETUP_USERSETTING_H */
