@@ -21,7 +21,7 @@
    files in /etc/setup/\* and create the mount points. */
 
 #if 0
-static const char *cvsid = "\n%%% $Id: install.cc,v 2.60 2003/03/17 22:23:33 rbcollins Exp $\n";
+static const char *cvsid = "\n%%% $Id: install.cc,v 2.63 2003/07/30 23:04:49 igor Exp $\n";
 #endif
 
 #include "win32.h"
@@ -455,8 +455,6 @@ do_install_thread (HINSTANCE h, HWND owner)
   num_installs = 0, num_uninstalls = 0, num_replacements = 0;
   rebootneeded = false;
 
-  next_dialog = IDD_DESKTOP;
-
   io_stream::mkpath_p (PATH_TO_DIR, String ("file://") + get_root_dir ());
 
   for (i = 0; Installer::StandardDirs[i]; i++)
@@ -658,7 +656,7 @@ void md5_one (const packagesource& source)
       // check the MD5 sum of the cached file here
       io_stream *thefile = io_stream::open (source.Cached (), "rb");
       if (!thefile)
-	throw new Exception ("__LINE__ __FILE__", String ("IO Error opening ") + source.Cached(), APPERR_IO_ERROR);
+	throw new Exception (TOSTRING(__LINE__) " " __FILE__, String ("IO Error opening ") + source.Cached(), APPERR_IO_ERROR);
       md5_state_t pns;
       md5_init (&pns);
       
@@ -668,7 +666,7 @@ void md5_one (const packagesource& source)
 	  md5_append (&pns, buffer, count);
       delete thefile;
       if (count < 0)
-	throw new Exception ("__LINE__ __FILE__", String ("IO Error reading ") + source.Cached(), APPERR_IO_ERROR);
+	throw new Exception (TOSTRING(__LINE__) " " __FILE__, String ("IO Error reading ") + source.Cached(), APPERR_IO_ERROR);
       
       md5_byte_t tempdigest[16];
       md5_finish(&pns, tempdigest);
@@ -678,6 +676,6 @@ void md5_one (const packagesource& source)
       log (LOG_BABBLE, String ("For file ") + source.Cached() + " ini digest is " + source.md5.print() + " file digest is " + tempMD5.print());
       
       if (source.md5 != tempMD5)
-	  throw new Exception ("__LINE__ __FILE__", String ("Checksum failure for ") + source.Cached(), APPERR_CORRUPT_PACKAGE);
+	  throw new Exception (TOSTRING(__LINE__) " " __FILE__, String ("Checksum failure for ") + source.Cached(), APPERR_CORRUPT_PACKAGE);
     }
 }
