@@ -1,6 +1,3 @@
-#ifndef CINSTALL_LOCALDIR_H
-#define CINSTALL_LOCALDIR_H
-
 /*
  * Copyright (c) 2001, Gary R. Van Sickle.
  *
@@ -16,6 +13,9 @@
  *
  */
 
+#ifndef SETUP_LOCALDIR_H
+#define SETUP_LOCALDIR_H
+
 // This is the header for the LocalDirPage class.  Allows the user to select
 // the local package directory (i.e. where downloaded packages are stored).
 
@@ -35,7 +35,6 @@ public:
   bool Create ();
 
   virtual void OnActivate ();
-  virtual void OnInit ();
   virtual long OnNext ();
   virtual long OnBack ();
   virtual long OnUnattended ()
@@ -44,5 +43,12 @@ public:
   };
 };
 
+#include "UserSetting.h"
+class LocalDirSetting : public UserSetting 
+{
+  public:
+    virtual void load();
+    virtual void save();
+};
 
-#endif
+#endif /* SETUP_LOCALDIR_H */
