@@ -17,7 +17,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: log.cc,v 2.12 2002/05/04 12:15:56 rbcollins Exp $\n";
+  "\n%%% $Id: log.cc,v 2.13 2002/06/27 11:01:10 rbcollins Exp $\n";
 #endif
 
 #include "win32.h"
@@ -48,6 +48,6 @@ log (enum log_level level, const char *fmt, ...)
   char buf[1000];
   va_list args;
   va_start (args, fmt);
-  vsprintf (buf, fmt, args);
+  vsnprintf (buf, 1000, fmt, args);
   log (level, String(buf));
 }
