@@ -451,7 +451,9 @@ packagemeta::set_requirements (trusts deftrust, size_t depth)
 {
   if (visited())
     return 0;
-  visited(true);
+  /* Only prevent further checks once we have been required by something else */
+  if (depth)
+    visited(true);
   int changed = 0;
   /* handle build-depends */
   if (depth == 0 && desired.sourcePackage ().picked())
@@ -551,9 +553,18 @@ void
 packagemeta::logAllVersions () const
 {
     for (set<packageversion>::iterator i = versions.begin();
-	 i != versions.end(); ++i)
+	 i != versions.end(); ++i) 
+      {
 	log (LOG_BABBLE) << "    [" << trustLabel(*i) <<
 	  "] ver=" << i->Canonical_version() << endLog;
+	if (i->depends()->size()) 
+	{
+	  std::ostream & logger = log (LOG_BABBLE);
+	  logger << "      depends=";
+	  dumpAndList(i->depends(), logger);
+	  logger << endLog;
+	}
+      }
 #if 0
     log (LOG_BABBLE) << "      inst=" << i->
       /* FIXME: Reinstate this code, but spit out all mirror sites */
