@@ -19,7 +19,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: root.cc,v 2.12 2002/11/09 13:44:54 rbcollins Exp $\n";
+  "\n%%% $Id: root.cc,v 2.15 2003/07/29 14:14:06 maxb Exp $\n";
 #endif
 
 #include "win32.h"
@@ -40,7 +40,7 @@ static const char *cvsid =
 
 using namespace std;
 
-StringOption RootOption ("", 'R', "root", "Root installation directory");
+StringOption RootOption ("", 'R', "root", "Root installation directory", false);
 
 static int rb[] = { IDC_ROOT_TEXT, IDC_ROOT_BINARY, 0 };
 static int su[] = { IDC_ROOT_SYSTEM, IDC_ROOT_USER, 0 };
@@ -177,6 +177,12 @@ RootPage::OnInit ()
   load_dialog (GetHWND ());
 }
 
+bool
+RootPage::wantsActivation() const
+{
+  return (source != IDC_SOURCE_DOWNLOAD);
+}
+
 long
 RootPage::OnNext ()
 {
@@ -194,8 +200,6 @@ RootPage::OnNext ()
   else if (directory_has_spaces () && (IDNO == yesno (h, IDS_ROOT_SPACE)))
     return -1;
 
-  NEXT (IDD_LOCAL_DIR);
-
   log (LOG_PLAIN, String ("root: ") + get_root_dir () + 
        (root_text == IDC_ROOT_TEXT ? " text" : " binary")  +
        (root_scope == IDC_ROOT_USER ? " user" : " system"));
@@ -209,7 +213,6 @@ RootPage::OnBack ()
   HWND h = GetHWND ();
 
   save_dialog (h);
-  NEXT (IDD_SOURCE);
   return 0;
 }
 
