@@ -1,6 +1,3 @@
-#ifndef CINSTALL_THREEBAR_H
-#define CINSTALL_THREEBAR_H
-
 /*
  * Copyright (c) 2001, Gary R. Van Sickle.
  *
@@ -16,6 +13,9 @@
  *
  */
 
+#ifndef SETUP_THREEBAR_H
+#define SETUP_THREEBAR_H
+
 // This is the header for the ThreeBarProgressPage class.  It is a fairly generic
 // progress indicator property page with three progress bars.
 
@@ -32,6 +32,8 @@
 #define WM_APP_START_SETUP_INI_DOWNLOAD    WM_APP+6
 #define WM_APP_SETUP_INI_DOWNLOAD_COMPLETE WM_APP+7
 // desktop.h: WM_APP_UNATTENDED_FINISH WM_APP+8
+#define WM_APP_START_POSTINSTALL           WM_APP+9
+#define WM_APP_POSTINSTALL_THREAD_COMPLETE WM_APP+10
 
 class ThreeBarProgressPage:public PropertyPage
 {
@@ -51,9 +53,7 @@ class ThreeBarProgressPage:public PropertyPage
   void EnableSingleBar (bool enable = true);
 
 public:
-    ThreeBarProgressPage ()
-  {
-  };
+  ThreeBarProgressPage ();
   virtual ~ ThreeBarProgressPage ()
   {
   };
@@ -84,4 +84,4 @@ public:
 };
 
 
-#endif // CINSTALL_THREEBAR_H
+#endif /* SETUP_THREEBAR_H */
