@@ -14,6 +14,9 @@
  *
  */
 
+#ifndef SETUP_WIN32_H
+#define SETUP_WIN32_H
+
 /* The inital purpose of this file was limit the number of Win32 headers we
    actually have to parse.  The Setup program only uses a few of them,
    so there's no point in parsing them all (even lean-n-mean).  Doing
@@ -21,9 +24,6 @@
    class which provides runtime information about the OS
  */
 
-#ifndef SETUP_WIN32_H
-#define SETUP_WIN32_H
-
 #define NOCOMATTRIBUTE
 
 #include <stdarg.h>
@@ -32,7 +32,11 @@
 /* We want a minimum IE version of 3 */
 #define _WIN32_IE 0x0300
 /* libstdc++-v3 _really_ dislikes min & max defined as macros. */
+/* As of gcc 3.3.1, it defines NOMINMAX itself, so test first,
+ * to avoid a redefinition error */
+#ifndef NOMINMAX
 #define NOMINMAX
+#endif
 #include <windows.h>
 #if HAVE_ALLOCA_H
 #include <alloca.h>
@@ -63,5 +67,4 @@ class Win32 {
 };
 
 #endif //_cplusplus
-#endif // SETUP_WIN32_H
-
+#endif /* SETUP_WIN32_H */
